import sys
import speech_recognition as sr
from pydub import AudioSegment
import imageio_ffmpeg as ffmpeg

def transcribe_audio(file_path, output_path):
    recognizer = sr.Recognizer()

    # Ensure ffmpeg is available
    ffmpeg_path = ffmpeg.get_ffmpeg_exe()
    print(f"Using ffmpeg at {ffmpeg_path}")

    # Check if the file is mp3, if so convert it to wav
    if file_path.endswith('.mp3'):
        print("Converting mp3 to wav...")
        sound = AudioSegment.from_file(file_path, format="mp3")
        file_path = file_path.replace(".mp3", ".wav")
        sound.export(file_path, format="wav")

    # Load the audio file
    with sr.AudioFile(file_path) as source:
        audio_data = recognizer.record(source)
        # Try to recognize the speech in the audio
        try:
            text = recognizer.recognize_google(audio_data)
            with open(output_path, 'w') as f:
                f.write(text)
            print(f"Transcription saved to {output_path}")
        except sr.UnknownValueError:
            print("Could not understand audio")
        except sr.RequestError as e:
            print(f"Could not request results; {e}")

if __name__ == "__main__":
    if len(sys.argv) != 3:
        print("Usage: python3 xscribe.py path/to/file path/to/transcription.txt")
    else:
        file_path = sys.argv[1]
        output_path = sys.argv[2]
        transcribe_audio(file_path, output_path)
